const base = require('./utils/applet.base.js');
const api = require('./utils/applet.api.js');
const $utils = require('./utils/applet.validate.js')

/**
 * @param {Object} param
 * @param {Object} onSuccess
 * @param {Object} onFailure
 * @param {Object} complete
 * 人脸认证入口
 */
function face(param, onSuccess, onFailure, complete) {
	if (base.isApp()) { //app
		checkAlive(param, onSuccess, onFailure, complete);
	}else {
		// #ifdef MP-WEIXIN
		var data = {}; //返回数据
		wx.startFacialRecognitionVerify({
			name: param.name,
			idCardNumber: param.idCardNumber,
			checkAliveType: 2,
			success: function(res) {
				uni.showToast({
					title: '人脸识别成功',
					icon: 'none'
				})
				data.aac002 = param.idCardNumber
				data.code = "1"
				data.message = "人脸识别成功"
				if(onSuccess) {
					onSuccess(data)
				}
			},
			fail: function(res) {
				if(res.errCode == 90100) {
					uni.showToast({
						title: '用户取消了业务流程，主动退出',
						icon: 'none'
					})
				}
				data.aac002 = param.idCardNumber
				data.code = res.errCode
				data.message = res.errMsg
				if (onFailure) {
					onFailure(data)
				}
			},
			complete: function(res) {
				if (complete) {
					complete(data)
				}
			}
		})
		// #endif
		// #ifdef MP-ALIPAY
		try {
			var data = {}; //返回数据
			//这里需要单独申请支付宝小程序的人脸认证 https://opendocs.alipay.com/mini/introduce/alipay-verfify
			var alParam = {
				cert_name: param.name,
				cert_no: param.idCardNumber,
				phone_no: param.tel
			}
			base.post("/custom/alipay/identityCheck.do", alParam, sdata => {
				let reData = sdata.resultData.data;
				if(reData.success){
					/**
					  * 唤起认证流程
					  * 参数: certifyId、url 需要通过支付宝 openapi 开放平台网关接口获取
					  * 详细说明可查看文档下方的参数说明
					 **/
					my.startAPVerify({
						url: reData.certifyUrl,
						certifyId: reData.verifyId,
						success: function (res) {
							if(res.resultStatus == '9000') {
								uni.showToast({
									title: '人脸识别成功',
									icon: 'none'
								});
								data.aac002 = param.idCardNumber
								data.code = "1"
								data.message = "人脸识别成功"
								if(onSuccess) {
									onSuccess(data)
								} 
							}else {
								let msg = '';
								if(res.resultStatus == '6001'){
									msg = '用户取消了业务流程，主动退出';
								}else if(res.resultStatus == '6002') {
									msg = '网络异常';
								}else if(res.resultStatus == '4000') {
									msg = '业务异常';
								}else {
									msg = '其他错误';
								}
								uni.showToast({
									title: msg,
									icon: 'none'
								});
								data.aac002 = param.idCardNumber
								data.code = res.resultStatus
								data.message = msg
								if (onFailure) {
									onFailure(data)
								}
							}
						},
						fail: function (res) {
							uni.showToast({
								title: '调用失败',
								icon: 'none'
							})
							console.log("调用失败:" + JSON.stringify(res))
							data.aac002 = param.idCardNumber
							data.code = res.resultStatus
							data.message = res.errMsg
							if (onFailure) {
								onFailure(data)
							}
						},
						complete: function(res) {
							if (complete) {
								complete(data)
							}
						}
					});
				}else {
					console.log("000000原因：" + reData.msg)
					data.aac002 = param.idCardNumber
					data.code = "000000"
					data.message = "身份校验失败，请使用下方账号密码方式登录"
					if (onFailure) {
						onFailure(data)
					}
				}
			}, fData => {
				console.log("000001原因：" + JSON.stringify(fData))
				data.aac002 = param.idCardNumber
				data.code = "000001"
				data.message = "身份校验失败，请使用下方账号密码方式登录"
				if (onFailure) {
					onFailure(data)
				}
			});
		} catch (e) {
			uni.showToast({
				title: '请求错误：' + '[' + e.message + ']' + '[' + JSON.stringify(e) + ']',
				icon: 'none',
				duration: 2000,
				mask: true
			});
		}
		// #endif
	}
}

//#ifdef MP-ALIPAY
function ready(callback) {
    // 如果jsbridge已经注入则直接调用 
    if (window.AlipayJSBridge) {
		callback && callback ();
	} else  {
		// 如果没有注入则监听注入的事件 
		document.addEventListener ( 'AlipayJSBridgeReady' ,  callback ,  false );
	}
}
// startBizService 接口仅在支付宝 10.0.15 及以上支持 
// 需要接入者自行做下版本兼容处理 ！！ 
function startAPVerify ( options ,  callback ) {
    AlipayJSBridge . call ( 'startBizService' , {
      name :  'open-certify' ,
      param :  JSON . stringify ( options ),
   },  callback );
}
//#endif
/**
 * 调用app人脸识别
 * @param {Object} param
 * @param {Object} onSuccess
 */
function checkAlive(param, onSuccess, onFailure, complete) {
	if(md.systemType == 'harmony') { //鸿蒙
		console.log("鸿蒙")
		hmzhy.checkAlive({
			singleAliveMotionTime:10,
			aliveMotionNum:2,
			cameraId:1
		}, (ret, err)=> {
			if(ret.status) {
				// 图片base64压缩 （base64过大，公安接口校验不通过）
				$utils.compressBase64(ret.photo, 0.5, decBase64 => {
					if(param.authType && param.authType == "zhy") {
						//智慧眼
						zhy_authFn(param.idCardNumber, param.name, decBase64, onSuccess, onFailure, complete);
					}else {
						//调用公安实人认证接口
						identification(param.idCardNumber, param.name, param.tel, decBase64, onSuccess, onFailure, complete);
					}
				});
			}else {
				uni.showToast({
					title: ret.msg,
					type: 'default',
					icon: "none",
					
				})
			}
		});
	}else { //默认安卓
		//请求用户获取手机相机权限、存储权限
		md.requireApiPermiss({type:['CAMERA','STORAGE']}, ret=>{
			if(ret.status) {
				mdGZYLZHY.init();
				mdGZYLZHY.startRecog({
				    timeout:40,
				    poseNum:1,
				    aliveFirstMotion:2, //首个活体动作(2摇头3抬头4低头5张嘴6眨眼)
				    onlyAlive:1,
				    isVoice:1,
				    qualitySwitch:1,
				    isFixMotion:0, //是否固定活体动作
				    lostFace:4, //人脸检测过程中失败次数限制
					cameraId:1
				}, reData => {
					if(reData.code === 0) {
						var base64 = JSON.parse(reData.data).images[0];
						if(param.authType && param.authType == "zhy") {
							//智慧眼
							zhy_authFn(param.idCardNumber, param.name, base64, onSuccess, onFailure, complete);
						}else {
							//调用公安实人认证接口
							identification(param.idCardNumber, param.name, param.tel, base64, onSuccess, onFailure, complete);
						}
					}else {
						if(reData.code == "-9") {
							uni.showToast({
								title: "用户操作取消",
								type: 'default',
								icon: "none"
							})
						} else {
							uni.showToast({
								title: "未知错误",
								type: 'default',
								icon: "none"
							})
							let temp = {
								aac002: aac002,
								message: "未知错误",
								code: -1
							};
							if(onFailure) {
								onFailure(temp)
							}
						}
					}
				});
			}
		});
	}
}

/**
 * 智慧眼人脸认证（返回人脸认证结果-是否人脸通过）
 * @param {Object} aac002
 * @param {Object} aac003
 * @param {Object} base64
 * @param {Object} onSuccess
 * @param {Object} onFailure
 * @param {Object} complete
 */
function zhy_authFn(aac002, aac003,base64, onSuccess, onFailure, complete) {
	uni.showLoading({
		mask: true
	});
	var param = {
		"aac003": aac003, //姓名
		"aac002": aac002, //证件号
		"invokeTime": new Date().getTime(),
		"sysType": md.systemType,
		"base64": base64,
		"sysVersion": "",
		"terminalType": "40003", //终端类型
	}
	base.post("/custom/zhyAuth/zhyFaceFn.do", param, sData => {
		uni.hideLoading();
		var resultData = sData.resultData;
		if(resultData) {
			let temp = {
				aac002: aac002,
				message: resultData.data.message
			};
			if(sData.success && resultData.data.code == '1') {
				temp.code = 1;
				uni.showToast({
					title: '人脸识别成功',
					icon: 'none'
				})
				if (onSuccess) {
					onSuccess(temp)
				}
			}else {
				temp.code = -1;
				uni.showToast({
					title: '人脸识别失败',
					icon: 'none'
				})
				if (onFailure) {
					onFailure(temp)
				}
			}
			if(complete) {
				complete(temp)
			}
		}else {
			uni.showToast({
				title: JSON.stringify(resultData),
				type: 'default',
				icon: "none"
			})
		}
	}, fData => {
		uni.hideLoading();
		uni.showToast({
			title: JSON.stringify(fData),
			type: 'default',
			icon: "none"
		})
	});
}

/**
 * 调用公安接口比对数据
 * @param {Object} aac002
 * @param {Object} aac003
 * @param {Object} phoneNum
 * @param {Object} base64
 * @param {Object} onSuccess
 */
function identification(aac002, aac003, phoneNum, base64, onSuccess, onFailure, complete) {
	uni.showLoading({
		mask: true
	});
	let temp = {
		aac002: aac002
	};
	var param = {
		aac002: aac002,
		aac003: aac003,
		mobile: phoneNum,
		photo: base64 //照片的base64格式
	};
	base.post("/custom/approve/identification.do", param, data => {
		uni.hideLoading();
		if(data.resultData.code == "200") {
			let data_ = data.resultData.data;
			let code = data_.code;
			let message = data_.msg;
			temp.message = message;
			if(data_.code == "0"){
				uni.showToast({
					title: '人脸识别成功',
					icon:'none'
				})
				temp.code = 1;
				if(onSuccess) {
					onSuccess(temp)
				}
			} else {
				uni.showToast({
					title: temp.message,
					icon:'none'
				})
				temp.code = -1;
				if(onFailure) {
					onFailure(temp)
				}
			}
		} else {
			uni.showToast({
				title: data.msg,
				icon:'none'
			})
			temp.message = data.msg;
			temp.code = -1;
			if(onFailure) {
				onFailure(temp)
			}
		}
	},data=>{
		console.log("结果——>："+JSON.stringify(data))
		uni.hideLoading();
		uni.showToast({
			title: data.message,
			icon:'none'
		})
		temp.message = data.message;
		temp.code = -1;
		if(onFailure) {
			onFailure(temp)
		}
	});
}
// 人脸识别
function faceCheck(idCard, onSuccess) {
	faceDetector.detect({
		"detectMode": 4
	}, (ref, err) => {
		if (ref.code == "0") {
			/**执行成功*/
			let img_cj = ref.faceDetectInfo.base64;
			queryImg(idCard, img_cj, onSuccess);
		} else if (ref.code == "1") {
			md.toast({
				msg: '摄像头不允许操作',
				duration: 4000,
				location: 'middle'
			});
		} else if (ref.code == "2") {
			md.toast({
				msg: '其他未知错误',
				duration: 4000,
				location: 'middle'
			});
		} else if (ref.code == "3") {
			md.toast({
				msg: '超时',
				duration: 4000,
				location: 'middle'
			});
		} else if (ref.code == "4") {
			md.toast({
				msg: '用户操作返回 ',
				duration: 4000,
				location: 'middle'
			});
		};

	});
}

//根据身份证号码获取社保人脸信息
function queryImg(idCard, img_cj, onSuccess) {
	let param = {};
	param.jybh = "AQ_image";
	param.aac002 = idCard;
	appFaceRequest('http://222.82.215.217:10016/ksapp/app/queryData', param, data => {
		if(data.body.code=='-1'){
			md.toast({
				msg:'网络异常,获取比对人脸信息失败',
				duration:4000,
				location:'middle'
			})
			return
		}
		if (data.body.output.length > 0) {
			let img_Sb = data.body.output[0].ykk051;
			checkInfo(img_cj, img_Sb, onSuccess);
		} else {
			//没有获取到人脸信息
			md.toast({
				msg: '持卡库中暂无该人员人脸信息，无法进行人脸校验',
				duration: 4000,
				location: 'middle'
			});
		}
	})
}

//校验人脸信息
function checkInfo(img_cj, img_Sb, onSuccess) {
	let param = {};
	param.jybh = "scrz";
	param.base641 = img_cj;
	param.base642 = img_Sb;
	appFaceRequest('http://222.82.215.217:10016/ksapp/app/queryData', param, data => {
		if (!data.body.similarity) {
			md.toast({
				msg: '人脸校验失败',
				duration: 4000,
				location: 'middle'
			});
			return
		}
		if (data.body.similarity < 52) {
			md.toast({
				msg: '温馨提示，人脸校验结果不是同一个人',
				duration: 4000,
				location: 'middle'
			});
		} else {
			uni.showToast({
				title: '人脸识别成功',
				icon: 'none'
			})
			// 人脸比对的成功
			onSuccess(data)
		}
	});
}

/**
 * App人脸识别请求
 * @param {Object} url 调平安人脸的地址
 * @param {Object} onSuccess 成功回调
 * @param {Object} params  需要的参数
 */
function appFaceRequest(url, params, onSuccess) {
	uni.showLoading({
		mask: true
	});
	setTimeout(function() {
		md.ajax({
			url: url,
			method: 'post',
			returnAll: true,
			timeout: 180,
			data: {
				values: params
			},
			headers: base.dealHeader('post')
		}, function(ret, err) {
			uni.hideLoading();
			if (!ret) {
				uni.showToast({
					title: NET_ERROR,
					icon: 'none',
					duration: 2000,
					mask: true
				});
				return;
			}
			onSuccess(ret);
		});
	}, 400)
}

//消息推送监听
function setJpush() {
	if(base.isApp()){
		//用户关闭了消息推送
		let push = uni.getStorageSync('push');
		if(push != "0"){
			let _this = this
			//初始化消息推送
			jPush.init(function(rets) {
				if (rets.status) {
					//绑定登录用户
					_this.changeJpush()
				}
			});
		}
	}
}

//更换监听用户
function changeJpush() {
	if(base.isApp()){
		//用户关闭了消息推送
		let push = uni.getStorageSync('push');
		if(push != "0"){
			//绑定别名
			let user = base.getUser(true, true)
			if (user) {
				let param = {
					alias: user.accountBo.account,
					tags: [user.accountBo.account]
				}
				jPush.bindAliasAndTags(param, function(ret) {});
				jPush.getRegistrationId(function(ret) {
					let registrationId = ret.id;
					console.log("jPush.getRegistrationId:"+registrationId)
				});
				//极光推送开启监听
				jPush.setListener(
					function(ret,err) {
						//当应用运行时收到消息回调
						console.log("---开启ret---", JSON.stringify(ret));
					}
				);
				//极光推送回调
				md.addEventListener({
					name:'notifyclicked'
				},function(ret,err){
					//点击消息后回调
					console.log("---回调ret---", JSON.stringify(ret));
				});
			};
		}
	}
}


/**
 * 获取url的参数对象
 * @param {Object} params 完整url路径
 */
function getUrlObject(params) {
	let url = decodeURIComponent(params)
	url = url.slice(url.indexOf("?") + 1)
	url = url.split('&')
	let param = {}
	for (let i = 0; i < url.length; i++) {
		let key = url[i].slice(0, url[i].indexOf('='))
		let value = url[i].slice(url[i].indexOf('=') + 1)
		param[key] = value
	}
	return param
}

/**
 * 解密社保卡页面返回的参数
 * @param {Object} security 返回参数的对应该名称字段
 * @param {Object} onSuccess
 * @param {Object} onFailure
 */
function decryptSocial(security, onSuccess, onFailure) {
	base.post('/custom/social/decryptHtmlSign.do', {
		'security': security
	}, data => {
		onSuccess(data.resultData.data)
	}, data => {
		if (onFailure) {
			onFailure(data)
		} else {
			uni.showToast({
				title: '网络错误',
				icon: 'none'
			})
		}
	})
}

//通过身份证查询对应用户姓名
function getQ001(certNo, onSuccess, onFailure) {
	//获取基本信息-姓名
	let param1 = {
		apiCode: 'SB_Q001',
		complexParam: JSON.stringify({
			aac002: certNo,
			//区域编号
			yab139: uni.getStorageSync("address").value.substr(0, 4)
		})
	}
	api.getOldData(param1, data1 => {
		if (data1.message) {
			if (onFailure) {
				onFailure(data1)
			} else {
				uni.showToast({
					title: data1.message + '请检查社保卡地区选择',
					duration: 3000,
					icon: 'none'
				})
			}
			return
		}
		onSuccess(data1.output.resultset[0])
	});
}

/**不做登录，跳转方法
 * @param {Object} param
 */
function justCheckService(param) {
	//1.个人 2.单位
	let type = param.channelId == base.CHANNEL_ID_UT01?1:2
	if(type==2&&!user.accountBo.parentAccounts){
		uni.showToast({
			title: '个人用户无法进行单位代办',
			icon: 'none',
			duration: 3000
		})
		return
	}
	let params = {
		'channelId': param.channelId,
		'handleItemCode': param.handleItemCode
	}
	base.post('/custom/service/getSinService.do', params, data => {
		//查询事项信息
		if (data.resultData.data) {
			let service = data.resultData.data
			params.handleItemName = service.handleItemName
			//单位和个人都要判断
			if (service.serviceSelfext.channelType.indexOf('4') == -1) {
				uni.showToast({
					title: '当前服务不支持移动端办理,请前往对应的【 在线网站 】或 【 服务网点 】办理',
					icon: 'none',
					duration: 5000
				})
				return
			}
			if(service.isPhoneLogin=='1'&&!base.isApp()){
				uni.showToast({
					title:'请在APP上办理该服务',
					icon:'none',
					duration:3000
				})
				return
			}
			//个人
			if(type==1){
				//服务对象自然人
				if (!service.serviceTarget||service.serviceTarget.indexOf('1') == '-1') {
					uni.showToast({
						title: '当前服务不支持个人办理',
						icon: 'none',
						duration: 3000
					})
					return
				}
				//获取对应的办理页面url
				if (service.serviceExt.serviceField1) {
					params.url = service.serviceExt.serviceField1
				} else {
					uni.showToast({
						title: '移动端暂无办理页面',
						icon: 'none',
						duration: 3000
					})
					return
				}
			}
			//单位
			if(type==2){
				//服务对象法人
				if (!service.serviceTarget||service.serviceTarget == '1') {
					uni.showToast({
						title: '当前服务不支持单位代办',
						icon: 'none',
						duration: 3000
					})
					return
				}
				//获取对应的办理页面url
				if (service.serviceExt.serviceField1) {
					params.url = service.serviceExt.serviceField1;	
				} else {
					uni.showToast({
						title: '移动端暂无办理页面',
						icon: 'none',
						duration: 3000
					})
					return
				}
			}
			if(param.isTrue) {
				base.navigate(service.accessUrl, true, params);
			}else {
				base.navigate(service.accessUrl, false, params);
			}
		} else {
			uni.showToast({
				title: '当前服务不支持移动端办理,请前往对应的【 在线网站 】或 【 服务网点 】办理',
				icon: 'none',
				duration: 5000
			})
			return
		}
	}, data => {
		uni.showToast({
			title: '获取事项信息失败',
			icon: 'none'
		})
		return
	});
}

/**
 * 校验服务权限并跳转
 * 需要channelId和handleItemCode
 * @param {Object} param
 */
function checkServiceAuth(param) {
	let user = base.getUser(true, true)
	if (!user) {
		uni.showToast({
			title: '请先登录后办理服务',
			icon: 'none',
			duration: 3000
		})
		return
	}
	//1.个人 2.单位
	let type = param.channelId == base.CHANNEL_ID_UT01?1:2
	if(type==2&&!user.accountBo.parentAccounts){
		uni.showToast({
			title: '个人用户无法进行单位代办',
			icon: 'none',
			duration: 3000
		})
		return
	}
	let params = {
		'channelId': param.channelId,
		'handleItemCode': param.handleItemCode
	}
	base.post('/custom/service/getSinService.do', params, data => {
		//查询事项信息
		if (data.resultData.data) {
			let service = data.resultData.data
			params.handleItemName = service.handleItemName
			//单位和个人都要判断
			if (service.serviceSelfext.channelType.indexOf('4') == -1) {
				uni.showToast({
					title: '当前服务不支持移动端办理,请前往对应的【 在线网站 】或 【 服务网点 】办理',
					icon: 'none',
					duration: 5000
				})
				return
			}
			if(service.isPhoneLogin=='1'&&!base.isApp()){
				uni.showToast({
					title:'请在APP上办理该服务',
					icon:'none',
					duration:3000
				})
				return
			}
			//个人
			if(type==1){
				//服务对象自然人
				if (!service.serviceTarget||service.serviceTarget.indexOf('1') == '-1') {
					uni.showToast({
						title: '当前服务不支持个人办理',
						icon: 'none',
						duration: 3000
					})
					return
				}
				//获取对应的办理页面url
				if (service.serviceExt.serviceField1) {
					params.url = service.serviceExt.serviceField1
				} else {
					uni.showToast({
						title: '移动端暂无办理页面',
						icon: 'none',
						duration: 3000
					})
					return
				}
			}
			//单位
			if(type==2){
				//服务对象法人
				if (!service.serviceTarget||service.serviceTarget == '1') {
					uni.showToast({
						title: '当前服务不支持单位代办',
						icon: 'none',
						duration: 3000
					})
					return
				}
				//获取对应的办理页面url
				if (service.serviceExt.serviceField1) {
					params.url = service.serviceExt.serviceField1;	
				} else {
					uni.showToast({
						title: '移动端暂无办理页面',
						icon: 'none',
						duration: 3000
					})
					return
				}
			}
			//判断是否有权限信息
			if (service.resConfig && service.resConfig.authType == "1" && service.resConfig.authValue) {
				//事项权限列表
				let authValueList = service.resConfig.authValue.split(",")
				let userAuthValue = user.accountBo.authTypeCodes
				//用户是否满足权限
				let authFlag = false
				for (let i = 0; i < authValueList.length; i++) {
					if (userAuthValue.indexOf(authValueList[i]) != '-1') {
						authFlag = true
					}
				}
				//通过事项权限校验
				if (authFlag) {
					if(service.serviceExt.serviceField2 == "1") {
						checkFace(service.accessUrl, params, user)
						return
					} else {
						/*  // 测试事项
						service.accessUrl = '/grfw/11520000009390615D252201400510200';
						params.url = 'pages/h5Link/oneCardZone/print/ownPayProofPrint';
						params.handleItemCode = '11520000009390615D252201400510200'; 
						*/
						base.navigate(service.accessUrl, false, params)
					}
				} else {
					//未通过权限校验 提示某认证未满足
					base.post('/custom/auth/authMap.do', {
						'type': '1'
					}, datas => {
						let authMap = datas.resultData.data
						let errMsg = '当前事项需要'
						for (let i = 0; i < authValueList.length; i++) {
							for (let j = 0; j < authMap.length; j++) {
								if (authValueList[i] == authMap[j].authTypeCode) {
									if (i != 0) {
										errMsg = errMsg + '或'
									}
									errMsg = errMsg + "【 " + authMap[j].authTypeName + " 】"
								}
							}
						}
						errMsg = errMsg + '的认证权限'
						uni.showToast({
							title: errMsg,
							duration: 4000,
							icon: 'none'
						})
					}, datas => {
						uni.showToast({
							title: '认证权限不足，请查看 【 我的->我的认证 】',
							duration: 4000,
							icon: 'none'
						})
					})
				}
			} else {
				if(service.serviceExt.serviceField2 == "1") {
					checkFace(service.accessUrl, params, user)
					return
				} else {
					base.navigate(service.accessUrl, false, params)
				}
			}
		} else {
			uni.showToast({
				title: '当前服务不支持移动端办理,请前往对应的【 在线网站 】或 【 服务网点 】办理',
				icon: 'none',
				duration: 5000
			})
			return
		}
	}, data => {
		/* uni.showToast({
			title: '获取事项信息失败',
			icon: 'none'
		}) */
		uni.showToast({
			title: JSON.stringify(data),
			icon: 'none'
		})
	})
}

//业务人脸认证
function checkFace(accessUrl, params, user) {
	//需要进行人脸认证
	uni.showModal({
	    title: '提示',
	    content: '该功能需要进行人脸认证，是否进行认证？',
		confirmText: "认证",
	    success: res=> {
	        if (res.confirm) {
				let dto = {
					aac002: user.naturalBo.certNo,
					aac003: user.naturalBo.name, 
					phoneNum: user.naturalBo.mobile
				}
				base.post('/custom/approve/addApproveInfo.do', dto, data => {
					let param = {
						idCardNumber: user.naturalBo.certNo, 
						name: user.naturalBo.name, 
						tel: user.naturalBo.mobile
					}
					face(param, data=> {
						base.post("/custom/approve/authResult.do", {aac002: user.naturalBo.certNo, code: "1", message: "认证成功"}, data => {
							base.navigate(accessUrl, false, params)
						},true);
					})
				})
	        } else if (res.cancel) {
	            return;
	        }
	    }
	});
}

//设置倒计时
function setCountDown(i) {
	uni.setStorageSync("countdown" + i, "60s")
	setTimeout(function() {
		uni.removeStorageSync("countdown" + i)
	}, 60000)
}

//获取倒计时
function getCountDown(i, callback) {
	let time = uni.getStorageSync("countdown" + i)
	if (time) {
		uni.showToast({
			title: '发送验证码过于频繁,请一分钟后再试',
			icon: 'none',
			duration: 3000
		})
		callback(false)
	} else {
		callback(true)
	}
}

/**
 * 返回带“年月日”的时间格式
 * 
 * @param {Object} value 需要格式化的日期
 */
function showDate(value) {
	var reVal = "";
	if(value) {
		value = value.toString();
		if(value.length == 8) {
			reVal = value.substring(0,4) + "年" + value.substring(4,6) + "月" + value.substring(6,8) + "日";
		}else if(value.length == 6) {
			reVal = value.substring(0,4) + "年" + value.substring(4,6) + "月";
		}else if(value.length == 4) {
			reVal = value.substring(0,4) + "年";
		}else{
			reVal = value;
		}
	}
	return reVal;
}

/**
 * 把yyyy-mm-dd 格式为yyyymm
 *
 * @param {*} value 需要格式化的日期
 */
function formatIssue(value) {
	var reg = /(\d{4})\-(\d{2})/;
	return value.slice(0, 7).replace(reg, "$1$2");
}

/**
 * 把yyyy-mm-dd 格式为yyyymmdd
 *
 * @param {*} value 需要格式化的日期
 */
function formatDateString(value) {
	var reg = /(\d{4})\-(\d{2})\-(\d{2})/;
	return value.replace(reg, "$1$2$3");
}

/**
 * @param {Object} dateTime 时间戳
 * @param {Object} fmt  格式:yyyy代表年份,MM代表月份,dd代表天数,hh代表小时,mm代表分钟,ss代表秒数
 */
function timeFormat(dateTime, fmt) {
	// 如果为null,则格式化当前时间
	if (!dateTime) dateTime = Number(new Date());
	// 如果dateTime长度为10或者13，则为秒和毫秒的时间戳，如果超过13位，则为其他的时间格式
	if (dateTime.toString().length == 10) dateTime *= 1000;
	let date = new Date(dateTime);
	let ret;
	let opt = {
		"y+": date.getFullYear().toString(), // 年
		"m+": (date.getMonth() + 1).toString(), // 月
		"d+": date.getDate().toString(), // 日
		"h+": date.getHours().toString(), // 时
		"M+": date.getMinutes().toString(), // 分
		"s+": date.getSeconds().toString() // 秒
		// 有其他格式化字符需求可以继续添加，必须转化成字符串
	};
	for (let k in opt) {
		ret = new RegExp("(" + k + ")").exec(fmt);
		if (ret) {
			fmt = fmt.replace(ret[1], (ret[1].length == 1) ? (opt[k]) : (opt[k].padStart(ret[1].length, "0")))
		};
	};
	return fmt;
}

/**
 * 获取当前时间
 * 格式:yyyy代表年份,MM代表月份,dd代表天数,hh代表小时,mm代表分钟,ss代表秒数
 */
function getCurrSysDate(format) {
	var date = new Date();
	var fmt = format.toString();
	if (fmt.indexOf("yy") !== -1) {
		if (fmt.indexOf("yyyy") !== -1) {
			fmt = fmt.replace("yyyy", date.getFullYear());
		} else {
			fmt = fmt.replace("yy", date.getFullYear().toString().substr(-2, 2));
		}
	}
	if (fmt.indexOf("MM") !== -1) {
		var m = date.getMonth() + 1;
		fmt = fmt.replace("MM", m.toString().length == 1 ? ("0" + m) : m);
	}
	if (fmt.indexOf("dd") !== -1) {
		var d = date.getDate();
		fmt = fmt.replace("dd", d.toString().length == 1 ? ("0" + d) : d);
	}
	if (fmt.indexOf("hh") !== -1) {
		fmt = fmt.replace("hh", date.getHours());
	}
	if (fmt.indexOf("mm") !== -1) {
		fmt = fmt.replace("mm", date.getMinutes());
	}
	if (fmt.indexOf("ss") !== -1) {
		fmt = fmt.replace("ss", date.getSeconds());
	}
	return fmt;
}

// 初始化 梆梆安全移动威胁感知
function initMdThreatPerception() {
	mdThreatPerception.init({
	    key: 'uqcq3zSV9h2aANaXQgO9bNEGfEZwobYH19KxUvngFTk0b09aE3J6FLRcTLOqCRsMwE29lmQW2Hut45HrGVLDROj1yS120DOpj/xFhuOxfp2H94AFlUVoRlOq//eTQWEX',
	    usageStats: false,
	    usageStatsAlways: false
	},function(ret){
		uni.setStorageSync("bb_sync",ret.code);
	})
}

module.exports = {
	face: face,
	appFaceRequest: appFaceRequest,
	setJpush: setJpush,
	changeJpush: changeJpush,
	getUrlObject: getUrlObject,
	decryptSocial: decryptSocial,
	getQ001: getQ001,
	checkServiceAuth: checkServiceAuth,
	setCountDown: setCountDown,
	getCountDown: getCountDown,
	checkAlive: checkAlive,
	showDate: showDate,
	formatIssue: formatIssue,
	formatDateString: formatDateString,
	timeFormat: timeFormat,
	getCurrSysDate: getCurrSysDate,
	justCheckService: justCheckService,
	initMdThreatPerception: initMdThreatPerception
}
