const base = require('./utils/applet.base.js');
const { login } = require('./utils/applet.user.js');

// 三方H5的数据配置
const h5BaseInfo = [
	{
		name: '劳动仲裁服务',
		value: 'ldzcxt',
		isIndexShow: false, //是否在首页显示独立的模块 (true时，isLogin和url必须有值)
		isLogin: true, // 是否需要登录
		url: 'https://rsrc.gzsrs.cn/ldzc/',//三方提供
		key: '8b25894ce7d55c5ab5afd40f9c86e8ef', //密钥（勿删）
		handleItemCodeArr: [ //当前H5(系统)配置的事项code  (根据事项code匹配对应系统的key)
			'11520000009390615D152201480110101'
		]
	},
	{
		name: '流动人才党员',
		value: 'ldrcdy',
		isIndexShow: true, //是否在首页显示独立的模块 (true时，isLogin和url必须有值)
		isLogin: true, // 是否需要登录
		url: 'https://rsrc.gzsrs.cn/rcportal/#/home' ,//三方提供
		key: '0bcdabd903d8d7fbf47f5fb530909b63', //密钥（勿删）
		handleItemCodeArr: [ //当前H5(系统)配置的事项code  (根据事项code匹配对应系统的key)
			'11520000009390615D152201480110102',
			'11520000009390615D152201480110103',
			'11520000009390615D152201480110104'
		]
	},
	{
		name: '继续教育平台',
		value: 'jxjypt',
		isIndexShow: false, //是否在首页显示独立的模块 (true时，isLogin和url必须有值)
		isLogin: true, // 是否需要登录
		url: 'http://gzjxjy.gzsrs.cn/mobile/#/pages/home/index' ,//三方提供
		key: '027f58f4be271362e04a3fce3461a411', //密钥（勿删）
		handleItemCodeArr: [ //当前H5(系统)配置的事项code  (根据事项code匹配对应系统的key)
			'11520000009390615D152201480110100'
		]
	},
	{
		name: '智慧劳务',
		value: 'zhlw',
		isIndexShow: false, //是否在首页显示独立的模块 (true时，isLogin和url必须有值)
		isLogin: true, // 是否需要登录
		url: 'https://zhlwm.gzldyg.cn/' ,//三方提供
		key: '443f0207a817cbf9142d3f2fcfb39454', //密钥（勿删）
		handleItemCodeArr: [ //当前H5(系统)配置的事项code  (根据事项code匹配对应系统的key)
			'11520000009390615D152201480110105'
		]
	}
]





/** H5对appSecret加密处理方法======>事项点击
 * @param {Object} obj
 * @param {Object} data
 */
function h5EncHandleFn(obj, data) {
	let h5Key = getH5KeyFn(obj.handleItemCode)
	if(!h5Key) {
		uni.showToast({
			title: "获取对应key失败！",
			icon: 'none',
			duration: 2000,
			mask: true
		})
		return;
	}
	var paramData = {
		"channelId": obj.channelId,
		"handleItemCode": obj.handleItemCode,
		"handleItemName": obj.handleItemName
	}
	var userId = data.loginUser.accountBo.userInfoId.toString();
	//添加data对象
	paramData.data = {};
	// 添加appSecret到data对象中
	paramData.data.appSecret = getAppSecret(userId, h5Key);
	// 三方H5实现跳转
	getPathToJump(paramData);
}



// 获取跳转地址
function getPathToJump(param) {
	var jumpParam = {
		data: param.data,
		titleName: param.handleItemName
	}
	//1.个人 2.单位
	let type = param.channelId == base.CHANNEL_ID_UT01?1:2
	if(type==2&&!user.accountBo.parentAccounts){
		uni.showToast({
			title: '个人用户无法进行单位代办',
			icon: 'none',
			duration: 3000
		})
		return
	}
	base.post('/custom/service/getSinService.do', {
		'channelId': param.channelId,
		'handleItemCode': param.handleItemCode
	}, data => {
		//查询事项信息
		if (data.resultData.data) {
			let service = data.resultData.data
			//单位和个人都要判断
			if (service.serviceSelfext.channelType.indexOf('4') == -1) {
				uni.showToast({
					title: '当前服务不支持移动端办理,请前往对应的【 在线网站 】或 【 服务网点 】办理',
					icon: 'none',
					duration: 5000
				})
				return
			}
			if(service.isPhoneLogin=='1'&&!base.isApp()){
				uni.showToast({
					title:'请在APP上办理该服务',
					icon:'none',
					duration:3000
				})
				return
			}
			//个人
			if(type==1){
				//服务对象自然人
				if (!service.serviceTarget||service.serviceTarget.indexOf('1') == '-1') {
					uni.showToast({
						title: '当前服务不支持个人办理',
						icon: 'none',
						duration: 3000
					})
					return
				}
				//获取对应的办理页面url
				if (service.serviceExt.serviceField1) {
					jumpParam.path = service.serviceExt.serviceField1
				} else {
					uni.showToast({
						title: '移动端暂无办理页面',
						icon: 'none',
						duration: 3000
					})
					return
				}
			}
			//单位
			if(type==2){
				//服务对象法人
				if (!service.serviceTarget||service.serviceTarget == '1') {
					uni.showToast({
						title: '当前服务不支持单位代办',
						icon: 'none',
						duration: 3000
					})
					return
				}
				//获取对应的办理页面url
				if (service.serviceExt.serviceField1) {
					jumpParam.path = service.serviceExt.serviceField1;
				} else {
					uni.showToast({
						title: '移动端暂无办理页面',
						icon: 'none',
						duration: 3000
					})
					return
				}
			}
			jumpToH5(jumpParam);
		} else {
			uni.showToast({
				title: '当前服务不支持移动端办理,请前往对应的【 在线网站 】或 【 服务网点 】办理',
				icon: 'none',
				duration: 5000
			})
			return
		}
	}, data => {
		uni.showToast({
			title: '获取事项信息失败',
			icon: 'none'
		})
		return
	})
}

// 执行跳转三方H5
function jumpToH5(data) {
	var h5_path = "/pages/other/web-view/sf_h5_web?path="+data.path
		if(data.data) {
			h5_path += "&data="+JSON.stringify(data.data)
		}
		if(data.titleName) {
			h5_path += "&titleName="+data.titleName
		}
	uni.navigateTo({
		url: h5_path
	})
}

// 获取三方H5(系统)对应配置的key
function getH5KeyFn(code) {
	var key = '';
	h5BaseInfo.forEach((item, index) => {
		for (var i = 0; i < item.handleItemCodeArr.length; i++) {
			if(item.handleItemCodeArr[i] == code){
				key = item.key;
				break;
			}
		}
		if(key) {
			return key;
		}
	})
	return key;
}

// 获取appSecret
function getAppSecret(userId, key) {
	// 加密appSecret
	return base.AES.encrypt(userId +","+ new Date().getTime().toString(), key).replace(/[+]/g, '%2B');
}


module.exports = {
	h5BaseInfo,
	h5EncHandleFn,
	jumpToH5,
	getAppSecret
}