//引入基础方法
const base = require('./applet.base.js');
const util = require('./applet.validate.js');

/**
 * 请求地址
 */
const BASE_URL = base.BASE_URL

//老协同使用
function getOldData(param,onSuccess,onFailure){
	base.post('/custom/common/getData.do',param,data=>{
		let result = data.resultData.data
		if(result){
			if(result.code==1){
				onSuccess(result)
			}else{
				if(onFailure){
					onFailure(result)
				}else{
					uni.showToast({
						title:result.message,
						icon:'none',
						duration:2000,
						mask:true
					})
				}
			}
		}else{
			uni.showToast({
				title:'网络错误，请重试',
				icon:'none',
				duration:2000,
				mask:true
			})
		}
	},data=>{
		if(onFailure){
			onFailure(data)
		}else{
			uni.showToast({
				title:data.message,
				icon:'none',
				duration:2000,
				mask:true
			})
		}
	})
}

/**
 * 通用配置接口调用 新协同使用
 * @param {Object} param
 * @param {Object} onSuccess
 */
function getData(param,onSuccess,onFailure){
	base.post('/custom/common/getData.do',param,data=>{
		let result = data.resultData.data
		if(result){
			if(result.code==200 || result.code==1){
				onSuccess(result)
			}else{
				uni.showToast({
					title:result.message,
					icon:'none',
					duration:2000,
					mask:true
				})
				if(onFailure){
					onFailure(result)
				}
			}
		}else{
			uni.showToast({
				title:'网络错误，请重试',
				icon:'none',
				duration:2000,
				mask:true
			})
		}
	},data=>{
		uni.showToast({
			title:data.message,
			icon:'none',
			duration:2000,
			mask:true
		})
		if(onFailure){
			onFailure(data)
		}
	})
}

/**
 * 获取令牌
 */
function getToken(onSuccess,onFailure){
	base.post('/code/getToken.do',null, data => {
		if (data.message == "用户已登录") {
			data.resultData.data.loginUser.naturalBo.name = util.handleEscapeChar(data.resultData.data.loginUser.naturalBo.name);
		}
		onSuccess(data)
	},data=>{
		onFailure(data)
	})
}

/**
 * 获取静态资源访问路径
 */
function getRes(onSuccess,onFailure) {
	base.get('/model/getResPath.do', null, function(data) {
		onSuccess(data)
	}, function(data) {
		onFailure(data)
	});
}


/**
 * 获取图片验证码
 */
function getImg(onSuccess, onFailure) {
	uni.request({
		url: BASE_URL + '/code/getImgCode.do',
		method: 'GET',
		header: base.dealHeader('GET'),
		responseType: 'arraybuffer',
		success(res) {
			//把arraybuffer转成base64
			let base64 = uni.arrayBufferToBase64(res.data);
			base64 = ' data:image/gif;base64,' + base64;
			onSuccess(base64)
		},
		fail: function(error) {
			uni.hideLoading();
			// #ifdef MP-ALIPAY
			if (error.error == '12' ||
				error.error == '19') {

			} else {
				onFailure({
					errMsg: '出现了点小意外, 请稍后再试' +
						'[错误码:' + error.error + ']'
				});
			}
			// #endif
			// #ifndef MP-ALIPAY
			if (error.errMsg == 'request:fail ') {

			} else {
				onFailure(error);
			}
			// #endif
		}
	})
}

//上传图片或视频
function uploadImg(onSuccess, onFailure) {
	uni.chooseImage({
		success: (chooseImageRes) => {
			const tempFilePaths = chooseImageRes.tempFilePaths;
			uni.uploadFile({
				url: BASE_URL + '/base/uploadPlatformFile.do',
				filePath: tempFilePaths[0],
				header: base.dealHeader('post'),
				name: 'file',
				success: (data) => {
					if (data.statusCode == '200') {
						onSuccess(data.data)
					} else {
						onFailure(data.data)
					}
				}
			});
		}
	});
}

//获取拖拽验证码
function getDrag(onSuccess, onFailure) {
	base.post('/code/getDragCode.do', null, onSuccess, onFailure)
}

//校验验证码
function checkDrag(params, onSuccess, onFailure) {
	base.post('/code/checkCaptcha.do', params, onSuccess, onFailure)
}

/**
 * 获取字典，字典初始化
 * @param {Object} code 字典类型
 * @param {Object} value  码值
 */
function loadDict(code, callback) {
	let codeType = code.toUpperCase();
	let param = {
		codeType: codeType
	}
	base.post('/base/getDictText.do', param, data => {
		if (data.resultData.data) {
			uni.setStorageSync(codeType + "1", data.resultData.data);
			callback(data.resultData.data);
		}
	}, data => {
		uni.showModal({
			title: '温馨提示',
			content: data,
			showCancel: false
		})
	})
}

/**
 * 字典码值转换工具
 */
function getDict(code, value) {
	let codeType = code.toUpperCase()
	let data = uni.getStorageSync(codeType + '1')
	if (value) {
		let text = value
		for (let i = 0; i < data.length; i++) {
			if (data[i].value == value) {
				text = data[i].label
			}
		}
		return text
	}
	return data
}



/**
 * 通过module.exports方式提供给外部调用
 */
module.exports = {
	getToken: getToken,
	getRes: getRes,
	getImg: getImg,
	uploadImg: uploadImg,
	getDrag: getDrag,
	checkDrag: checkDrag,
	getDict: getDict,
	loadDict: loadDict,
	getData:getData,
	getOldData:getOldData
}
