/**
 * applet.base.js依赖
 */
const base = require('./applet.base.js');
const api = require('./applet.api.js');

const JSEncrypt = require('./jsencrypt.js');

const util = require('./applet.validate.js');

/**
 * 公钥 用于登录、注册的账号、密码加密,必须加密
 */
const publicKey = base.publicKey;


/**
 * function: 用户登录
 * @params    请求参数
 * @onSuccess 成功回调
 * @onFailure 失败回调
 */
function login(params, onSuccess, onFailure) {
	let param = JSON.parse(JSON.stringify(params))
	// 新建JSEncrypt对象
	let encryptor = new JSEncrypt();
	// 设置公钥
	encryptor.setPublicKey(publicKey);
	param['voucher'] = encryptor.encrypt(param['voucher']);
	param['wordpass'] = encryptor.encrypt(param['wordpass']);
	base.post('/login/login.do', param,
		onSuccess, onFailure);
}

/**
 * 自然人注册
 */
function naturalRegister(params, onSuccess, onFailure) {
	let param = JSON.parse(JSON.stringify(params))
	// 新建JSEncrypt对象
	let encryptor = new JSEncrypt();
	// 设置公钥
	encryptor.setPublicKey(publicKey);
	param['account'] = encryptor.encrypt(param['account']);
	param['wordpass'] = encryptor.encrypt(param['wordpass']);
	base.post('/register/naturalRegister.do', param, onSuccess, onFailure)
}

/**
 * 法人注册
 */
function legalRegister(params, onSuccess, onFailure) {
	let param = JSON.parse(JSON.stringify(params))
	// 新建JSEncrypt对象
	let encryptor = new JSEncrypt();
	// 设置公钥
	encryptor.setPublicKey(publicKey);
	param['account'] = encryptor.encrypt(param['account']);
	param['wordpass'] = encryptor.encrypt(param['wordpass']);
	base.post('/register/legalRegister.do', param, onSuccess, onFailure)
}

/**
 * function: 三方账户解绑
 */
function thirdUnBind(onSuccess, onFailure) {
	getCode(function(data) {
		let params = {
			code: data.code
		};
		base.post('/third/thirdUnBind.do', params,
			onSuccess, onFailure);
	}, onFailure);
}

/**
 * function: 三方账户绑定
 */
function thirdBind(onSuccess, onFailure) {
	getCode(function(data) {
		let params = {
			code: data.code
		};
		base.post('/third/thirdBind.do', params,
			onSuccess, onFailure);
	}, onFailure);
}

/**
 * 三方登录
 */
function thirdLogin(onSuccess, onFailure) {
	getCode(function(data) {
		let params = {
			code: data.code,
			userType: 'UT01'
		};
		base.post('/login/thirdLogin.do', params,
			onSuccess, onFailure);
	}, onFailure);
}

/**
 * 当前小程序是否绑定
 */
function isBind(onSuccess, onFailure) {
	getCode(function(data) {
		let params = {
			code: data.code
		};
		base.post('/third/currentBindStatus.do', params,
			onSuccess, onFailure);
	}, onFailure);
}

/**
 * function: 获取用户信息
 */
function getUser(onSuccess, onFailure) {
	base.post('/member/getUserInfo.do', null,
		data => {
			if (data.resultData.data) {
				data.resultData.data.loginUser.naturalBo.name = util.handleEscapeChar(data.resultData.data.loginUser.naturalBo.name);
				uni.setStorageSync("user", data.resultData.data);
			}
			onSuccess(data)
		}, data => {
			if(onFailure){
				onFailure(data)
			}else{
				uni.showToast({
					title:data.message,
					icon:'none'
				})
			}
		});
}


/**
 * 修改用户信息
 */
function modifyUser(type, params, onSuccess, onFailure) {
	let url = ''
	//自然人
	if (type == '1') {
		url = '/member/modifyNaturalInfo.do'
		//法人	
	} else {
		url = '/member/modifyLegalInfo.do'
	}
	base.post(url, params, onSuccess, onFailure)

}

/**
 * 找回密码
 */
function resetPwd(params, onSuccess, onFailure) {
	let param = JSON.parse(JSON.stringify(params))
	let encryptor = new JSEncrypt();
	// 设置公钥
	encryptor.setPublicKey(publicKey);
	param['account'] = encryptor.encrypt(param['account']);
	param['newwordpass'] = encryptor.encrypt(param['newwordpass']);
	base.post('/member/resetAccountWordpass.do', param, onSuccess, onFailure)
}

/**
 * 修改密码
 */
function modifyPwd(params, onSuccess, onFailure) {
	let param = JSON.parse(JSON.stringify(params))
	let encryptor = new JSEncrypt();
	// 设置公钥
	encryptor.setPublicKey(publicKey);
	param['account'] = encryptor.encrypt(param['account']);
	param['wordpass'] = encryptor.encrypt(param['wordpass']);
	param['newwordpass'] = encryptor.encrypt(param['newwordpass']);
	base.post('/member/modifyAccountWordpass.do', param, onSuccess, onFailure)
}

/**
 * 更改自然人手机
 */
function modifyMobile(params, onSuccess, onFailure) {
	base.post(memberUrl + '/member/modifyNaturalMobile.do', params, onSuccess, onFailure)
}

/**
 * 更改自然人邮箱
 */
function modifyEmail(params, onSuccess, onFailure) {
	base.post(memberUrl + '/member/modifyNaturalEmail.do', params, onSuccess, onFailure)
}

/**
 * function: 退出登录
 * @onSuccess 成功回调
 * @onFailure 失败回调
 */
function logout(onSuccess, onFailure) {
	base.post('/custom/member/logout.do', null, onSuccess, onFailure);
}

/**
 * 修改用户头像
 * @param {Object} onSuccess
 * @param {Object} onFailure
 */
function modifyHead(onSuccess, onFailure) {
	api.uploadImg(data => {
		data = JSON.parse(data).resultData.data
		let param = {
			fileId: data[0].fileId
		}
		base.post(memberUrl + '/member/modifyAccountHeadPortrait.do', param, datas => {
			onSuccess(data[0].fileId)
		}, onFailure)
	}, onFailure)
}

/**
 * 信息验重
 */
function checkRepeat(params, onSuccess, onFailure) {
	base.post('/member/queryRepeatUserInfo.do', params, onSuccess, onFailure);
}

/**
 * 代办授权事项绑定/解绑
 */
function modifyUserAuthagain(params, onSuccess, onFailure) {
	base.post('/member/modifyUserAuthagain.do', params, onSuccess, onFailure);
}

/**
 * 代办授权事项查询
 */
function queryUserAuthagain(params, onSuccess, onFailure) {
	base.post('/member/queryUserAuthagainPage.do', params, onSuccess, onFailure);
}

/**
 * function: 获取登录凭证，已封装好
 */
function getCode(onSuccess, onFailure) {
	// #ifdef MP-WEIXIN
	wx.login({
		success: function(data) {
			onSuccess({
				code: data.code
			});
		},
		fail: function(data) {
			onFailure({
				// message: '获取登录凭证失败'
				message: '请先[选择关联小程序]，才能获取相关授权'
			});
		}
	});
	// #endif
	// #ifdef MP-ALIPAY
	my.getAuthCode({
		scopes: ['auth_user'],
		success: res => {
			onSuccess({
				code: res.authCode
			});
		},
		fail: res => {
			onFailure({
				message: res.errorMessage
			});
		}
	})
	// #endif
}

//返回上一页
function toPrePage() {
	setTimeout(function() {
		let router = getCurrentPages();
		let prePage = '/' + router[router.length - 2].is;
		uni.reLaunch({
			url: prePage
		})
	}, 1500)
}

/**
 * 通过module.exports方式提供给外部调用
 */
module.exports = {
	thirdUnBind: thirdUnBind,
	thirdBind: thirdBind,
	getUser: getUser,
	logout: logout,
	login: login,
	thirdLogin: thirdLogin,
	naturalRegister: naturalRegister,
	legalRegister: legalRegister,
	isBind: isBind,
	modifyUser: modifyUser,
	resetPwd: resetPwd,
	toPrePage: toPrePage,
	modifyHead: modifyHead,
	modifyPwd: modifyPwd,
	modifyMobile: modifyMobile,
	modifyEmail: modifyEmail,
	checkRepeat: checkRepeat,
	modifyUserAuthagain: modifyUserAuthagain,
	queryUserAuthagain: queryUserAuthagain,
	getCode:getCode
}
