const numberReg = /^-?[1-9][0-9]?.?[0-9]*$/
const intReg = /^-?[1-9][0-9]*$/
const phoneReg = /^1[0-9]{10,10}$/
const emailReg = /^\w+([-+.']\w+)*@\w+([-.]\w+)*\.\w+([-.]\w+)*$/
const pwdReg = /^.{6,16}$/

/**
 * 转义匹配
 */
const ESCAPE_CHARACTERS = {
  'nbsp': ' ',
  'lt': '<',
  'gt': '>',
  'amp': '&',
  'apos': '\"',
  'ensp': '     ',
  'emsp': ' ',
  'quot': '"',
  'middot': '·',
  'brvbar': '¦',
  'mdash': '—',
  'ndash': '–',
  'ge': '≥',
  'le': '≤',
  'laquo': '«',
  'raquo': '»',
  'deg': '°',
  'bull': '•',
  'macr': '¯',
  '#64': '@',
  'ldquo': '“',
  'rdquo': '”',
  'rsquo': '‚',
  'lsquo': '‘',
}

/**
 * 不需要登录的事项ItemCode
 */
const notLogin_handleItemCode_arr = [
	'11520000009390615D252201401100101', //待遇资格认证
	'11520000009390615D252201420401101', //档案防伪查验
	'11520000009390615D252201401010200', //社保卡服务网点查询
	'11520000009390615D252201410100201', //招聘岗位查询
	'11520000009390615D252201410100203', //培训机构查询
	'11520000009390615D252201410100202', //招聘会查询
	'11520000009390615D252201410100204', //创业孵化基地查询
	'11520000009390615D252201401300400', //城乡居民基本养老保险养老金预测算
	'11520000009390615D252201401400200', //企业职工待遇测算
	'11520000009390615D252201401400401', //法定退休年龄计算器
	'11520000009390615D252201401400101', //社保地图
	'11520000009390615D252201430100210', //外出务工农村劳动力服务
	'11520000009390615D252201430100202', //零工市场
	'11520000009390615D252201430100299' //贵州就业一张网(找工作)
];

/**
 *  不需要通过 /pages/scopes/psmp/service/service 跳转的事项
 */
const notToServicePathJump_handleItemCode_arr = [
	'11520000009390615D252201401400101', //社保地图
	'11520000009390615D252201430100210', //外出务工农村劳动力服务
	'11520000009390615D252201430100202', //零工市场
	'11520000009390615D252201430100299', //贵州就业一张网(找工作)
	'11520000009390615D252201491101101' //培训考勤签到
];

/** 配置了主题服务，且不需要在页面显示的服务主题
 * @param {Object} val
 */
const notShowThemeServiceItemSdimItemCode = [
	'zggzapp', //中国贵州配置功能事项
	'jybtsl' //就业补贴申领
];

/**
 * 格式化身份证号 -隐藏部分号码
 */
function idcard(val) {
	if (!val) return;
	let news = val.substr(0, 3) + '***********' + val.substr(val.length-4, 4)
	return news
}

function name(val) {
	if (!val) return;
	let news = ''
	if (val.length > 2) {
		news = '**' + val.substr(val.length-1, 1)
	} else {
		news = '*' + val.substr(1, 1)
	}
	return news
}

/**
 * 格式化手机号
 */
function mobile(val) {
	if (!val) return;
	let news = val.substr(0, 7) + '****'
	return news
}

/**
 * 手机号中间部分格式化(11位手机号码)
 */
function showMobile(val) {
	if (!val) return;
	return val.substring(0, 3) + '******' + val.substring(9);
}

/** 名字校验方法（姓名只能汉字(包含生僻字)和·(符号)）
 * @param {Object} name
 */
function checkChineseName(name) {
	var textMap = {
		status: true,
		msg: ''
	};
	let reg = /^([\u2E80-\uFE4F]{2,18})$/gi;
	// 保留点后,用来校验的姓名,也是最终校验通过后返回的姓名
	let payerName = name.replaceAll("　", "")
	                  .replaceAll(" ", "")
	                  .replaceAll("•", "·")
	                  .replaceAll("．", "·");
	// 去除所有点后，用来校验的姓名
	let checkName = name.replaceAll("　", "")
	                  .replaceAll(" ", "")
	                  .replaceAll("•", "")
	                  .replaceAll("．", "")
	                  .replaceAll("·", "");
	if(checkName.length === 1){
		textMap.msg = "姓名至少包含两位汉字，请检查";
		textMap.status = false;
		return textMap;
	}
	if (reg.test(checkName)) {
		if(payerName.substring(0,1) === '·'){
			textMap.msg = "姓名第一位不能为·(符号)，请检查";
			textMap.status = false;
			return textMap;
		}
		if(payerName.substring(payerName.length - 1) === '·'){
			textMap.msg = "姓名最后不能为·(符号)，请检查";
			textMap.status = false;
			return textMap;
		}
		if(payerName.indexOf("··") !== -1){
			textMap.msg = "姓名不能有连续的·(符号)，请检查";
			textMap.status = false;
			return textMap;
		}
		return textMap;
	} else {
		textMap.msg = "姓名中只能包含【汉字】和·(符号)，请检查";
		textMap.status = false;
		return textMap;
	}
}

/**
 * 时间格式处理
 */
function time(val) {
	if (!val) return;
	let news = val.substr(0, 10)
	return news
}

function timestamp(timeStamp) {
	if(!timeStamp){
		return ''
	}
	var time = new Date(parseInt(timeStamp));
	var y = time.getFullYear();
	var m = time.getMonth() + 1;
	var d = time.getDate();
	var h = time.getHours();
	var mm = time.getMinutes();
	var s = time.getSeconds();
	return y + '-' + add0(m) + '-' + add0(d) + ' ' + add0(h) + ':' + add0(mm) + ':' + add0(s);
}

function add0(m) { return m < 10 ? '0' + m : m }

/**
 * 判断是否为app
 */
function isApp() {
	let flag = false;
	try {
		//获取app版本号
		let version = md.appVersion;
		flag = true;
	} catch (e) {
		flag = false;
	}
	return flag;
}

/**
 * 判断是否是ios
 */
function isIos() {
	try {
		if (md.systemType == "ios") {
			return true;
		}
		return false;
	} catch (e) {
		return false;
	}
}

/**
 * 获取身份证号中的出生日期、性别、年龄
 * @param idNumber
 * @returns {{birthday: string, sex: string, age: string}}
 */
function getIdNumberInfo(idNumber) {
	var birthday, sex, age;
	if(idNumber.length > 15) {
		birthday =  idNumber.substring(6, 10) + "-" + idNumber.substring(10, 12) + "-" + idNumber.substring(12, 14);
		if(parseInt(idNumber.substr(16, 1)) % 2 == 1){
			sex = "1";
		} else {
			sex = "2";
		}
		var myDate = new Date();
		var month = myDate.getMonth() + 1;
		var day = myDate.getDate();
		age = myDate.getFullYear() - idNumber.substring(6, 10) - 1;
		if (idNumber.substring(10, 12) < month || idNumber.substring(10, 12) == month && idNumber.substring(12, 14) <= day) {
			age++;
		}
	}else {
		birthday = "19"+idNumber.slice(6,8) + "-" + idNumber.slice(8,10) + "-" + idNumber.slice(10,12);
		if(parseInt(idNumber.substr(14, 1)) % 2 == 1){
			sex = "1";
		} else {
			sex = "2";
		}
		var myDate = new Date();
		var month = myDate.getMonth() + 1;
		var day = myDate.getDate();
		age = myDate.getFullYear() - Number("19"+idNumber.substring(6, 8)) - 1;
		if (idNumber.substring(8, 10) < month || idNumber.substring(8, 10) == month && idNumber.substring(10, 12) <= day) {
			age++;
		}
	}
	return {
		"birthday":birthday + "",
		"sex":sex +"",
		"age":age + "",
	}
}

/**某个时间与当前时间比较，是否超过一年
 * @param {Object} timeStr
 */
function checkIsOneYear(timeStr){
    //平年每年的毫秒数
    var ms = 31536000000; 
    //将yyyy-mm-dd时间转成数组
    var startArr = timeStr.split("-");
    //生成Date数据
    var start = new Date(parseInt(startArr[0]), parseInt(startArr[1])-1, parseInt(startArr[2]), 0, 0, 0);
 
    //取出年月，用于判断是否为闰年
    var startYear = start.getFullYear();
    var startMonth = start.getMonth();
    //闰年判断
    if(isLeapYear(startYear) && startMonth <= 2){
        //加一天
        ms += 86400000;
    }
 
    //对当前日期的处理,只取年月日，不要时分秒
    var nowDate = new Date();
    var now = nowDate.getFullYear() + "-" + (nowDate.getMonth()+1) + "-" +nowDate.getDate();
    var nowArr = now.split("-");
    var now = new Date(parseInt(nowArr[0]), parseInt(nowArr[1])-1, parseInt(nowArr[2]), 0, 0, 0);
 
    //当前时间-开始时间的毫秒数
    var intervalNow = Number(now)-Number(start);
    if(intervalNow > ms){
        return true;
    }else {
		return false;
	}
}
//闰年判断
function isLeapYear(year){
    if(year % 100 == 0){
        if(year % 400 == 0){
            return true;
        }
    } else if(year % 4 == 0){
        return true;
    }
    return false;
}

/**
 * 获取当前时间
 * 格式:yyyy代表年份,MM代表月份,dd代表天数,hh代表小时,mm代表分钟,ss代表秒数
 */
function getCurrSysDate(format) {
	var date = new Date();
	var fmt = format.toString();
	if (fmt.indexOf("yy") !== -1) {
		if (fmt.indexOf("yyyy") !== -1) {
			fmt = fmt.replace("yyyy", date.getFullYear());
		} else {
			fmt = fmt.replace("yy", date.getFullYear().toString().substr(-2, 2));
		}
	}
	if (fmt.indexOf("MM") !== -1) {
		var m = date.getMonth() + 1;
		fmt = fmt.replace("MM", m.toString().length == 1 ? ("0" + m) : m);
	}
	if (fmt.indexOf("dd") !== -1) {
		var d = date.getDate();
		fmt = fmt.replace("dd", d.toString().length == 1 ? ("0" + d) : d);
	}
	if (fmt.indexOf("hh") !== -1) {
		var hh = date.getHours();
		fmt = fmt.replace("hh", hh.toString().length == 1 ? ("0" + hh) : hh);
	}
	if (fmt.indexOf("mm") !== -1) {
		var mm = date.getMinutes();
		fmt = fmt.replace("mm", mm.toString().length == 1 ? ("0" + mm) : mm);
	}
	if (fmt.indexOf("ss") !== -1) {
		var ss = date.getSeconds();
		fmt = fmt.replace("ss", ss.toString().length == 1 ? ("0" + ss) : ss);
	}
	return fmt;
}

/**判断boolean类型（返回 true/false）
 * @param {Object} tem
 */
function booleanTypeFn(tem) {
	if(tem && (tem == true || tem == 'true')) {
		return true;
	}else {
		return false;
	}
}

/**字符串非空判断 (返回 true,flase)
 * @param {Object} str
 */
function isNotEmpty(str) {
	if(str != null && str != "null" && str != undefined && str.length > 0 && str.trim().length > 0) {
		return true;
	}
	return false;
}

// 处理转义字符
function handleEscapeChar(str) {
  return str.replace(new RegExp(`&(${ Object.keys(ESCAPE_CHARACTERS).join('|') });`, 'g'), (all, t) => {
    return ESCAPE_CHARACTERS[t]
  })
}

/**压缩base64图片
 * @param {Object} base64 需要压缩的原base64
 * @param {Object} multiple 压缩系数 0-1
 * @param {Object} onSuccess 回调 用来获取处理后的 base64
 */
function compressBase64(base64, multiple, onSuccess) {
	if (!base64) {
	    return
	}
	var isC = true
	if(base64.indexOf("data:image/png;base64,") == -1) { //添加 data:image/png;base64, 格式
		base64 = "data:image/png;base64," + base64
		isC = false
	}
	// 压缩方法
	let newImage = new Image()
	let quality = 0.6 // 压缩系数0-1之间
	newImage.src = base64
	newImage.setAttribute('crossOrigin', 'Anonymous') // url为外域时需要
	let imgWidth, imgHeight
	let w = undefined
	newImage.onload = () => {
	    // 通过改变图片宽高来实现压缩
	    w = newImage.width * multiple
	    imgWidth = newImage.width
	    imgHeight = newImage.height
	    let canvas = document.createElement('canvas')
	    let ctx = canvas.getContext('2d')
	    if (Math.max(imgWidth, imgHeight) > w) {
	        if (imgWidth > imgHeight) {
	            canvas.width = w
	            // 等比例缩小
	            canvas.height = w * (imgHeight / imgWidth)
	        } else {
	            canvas.height = w
	            // 等比例缩小
	            canvas.width = w * (imgWidth / imgHeight)
	        }
	    } else {
	        canvas.width = imgWidth
	        canvas.height = imgHeight
	        // quality 设置转换为base64编码后图片的质量，取值范围为0-1  没什么压缩效果
	        // 还是得通过设置 canvas 的宽高来压缩
	        quality = 0.6
	    }
	    ctx.clearRect(0, 0, canvas.width, canvas.height)
	    ctx.drawImage(newImage, 0, 0, canvas.width, canvas.height) //  // 这里面的 this 指向 newImage
	    let smallBase64 = canvas.toDataURL('image/jpeg', quality) // 压缩语句
	    // 如想确保图片压缩到自己想要的尺寸,如要求在50-150kb之间，请加以下语句，quality初始值根据情况自定
	    while (smallBase64.length / 1024 > 150) {
	        quality -= 0.01
	        smallBase64 = canvas.toDataURL('image/jpeg', quality)
	    }
	    // 防止最后一次压缩低于最低尺寸，只要quality递减合理，无需考虑
	    while (smallBase64.length / 1024 < 50) {
	        quality += 0.001
	        smallBase64 = canvas.toDataURL('image/jpeg', quality)
	    }
		if(!isC) { //返回符合原来的base64格式
			smallBase64 = smallBase64.split(",")[1]
		}
		// 必须通过回调函数返回，否则无法及时拿到该值，回调函数异步执行
	    onSuccess(smallBase64)
	}
}

module.exports = {
	timestamp:timestamp,
	time: time,
	name: name,
	idcard: idcard,
	mobile: mobile,
	showMobile: showMobile,
	isApp: isApp,
	isIos: isIos,
	getIdNumberInfo: getIdNumberInfo,
	checkIsOneYear: checkIsOneYear,
	isLeapYear: isLeapYear,
	booleanTypeFn: booleanTypeFn,
	isNotEmpty: isNotEmpty,
	notLogin_handleItemCode_arr: notLogin_handleItemCode_arr,
	notToServicePathJump_handleItemCode_arr: notToServicePathJump_handleItemCode_arr,
	notShowThemeServiceItemSdimItemCode: notShowThemeServiceItemSdimItemCode,
	handleEscapeChar: handleEscapeChar,
	compressBase64: compressBase64,
	checkChineseName: checkChineseName,
	getCurrSysDate: getCurrSysDate,
	isNumber: function(val) {
		return numberReg.test(val)
	},
	isInt: function(val) {
		return intReg.test(val)
	},
	isPhone: function(val) {
		return phoneReg.test(val)
	},
	isEmail: function(val) {
		return emailReg.test(val)
	},
	isPwd: function(val) {
		return pwdReg.test(val)
	},
	validate: function(data, rules) {
		let res = {
			isOk: true,
			errMsg: ''
		}
		if (!rules || !rules.length) {
			return res
		}
		for (let rule of rules) {
			// rule: {name:'', type:'', errMsg:'', min:1, max:2, eqName:'', required:boolean, regex:'', validator:function}
			if (!rule || !rule.name || !rule.type) {
				continue
			}
			// 如果值不存在
			if (!data[rule.name]) {
				// 如果是必填项就返回错误提示，required可以作为type是为了不同的type能给用户不同的提示
				if (rule.type === 'required' || rule.required) {
					res = {
						isOk: false,
						errMsg: rule.errMsg
					}
					if (!res.errMsg) {
						res.errMsg = '请输入必填项数据' // 默认提示
					}
					return res
				}
				// 如果不是必填项就跳过
				continue
			}
			switch (rule.type) {
				// required 上面已经判断过了
				case 'eq':
					if (data[rule.name] !== data[rule.eqName]) {
						res = {
							isOk: false,
							errMsg: rule.errMsg
						}
					}
					break
				case 'number':
					if (!numberReg.test(data[rule.name])) {
						res = {
							isOk: false,
							errMsg: rule.errMsg
						}
					}
					break
				case 'int':
					if (!intReg.test(data[rule.name])) {
						res = {
							isOk: false,
							errMsg: rule.errMsg
						}
					}
					break
				case 'phone':
					if (!phoneReg.test(data[rule.name])) {
						res = {
							isOk: false,
							errMsg: rule.errMsg
						}
					}
					break
				case 'email':
					if (!emailReg.test(data[rule.name])) {
						res = {
							isOk: false,
							errMsg: rule.errMsg
						}
					}
					break
				case 'pwd':
					if (!pwdReg.test(data[rule.name])) {
						res = {
							isOk: false,
							errMsg: rule.errMsg
						}
					}
					break
				case 'range': // 数字类型的值取值范围
					// {name: 'xxx', type: 'range', min: 6, max: 6, required: true, errMsg: 'xxx'}
					let val = data[rule.name]
					if (val) {
						if (numberReg.test(val)) {
							if (rule.min && val < rule.min) {
								res = {
									isOk: false,
									errMsg: rule.errMsg
								}
							} else if (rule.max && val > rule.max) {
								res = {
									isOk: false,
									errMsg: rule.errMsg
								}
							}
						} else {
							res = {
								isOk: false,
								errMsg: rule.errMsg
							}
						}
					}
					break
				case 'lengthRange': // 字符串长度取值范围
					// {name: 'xxx', type: 'lengthRange', min: 6, max: 6, errMsg: 'xxx'}
					let le = data[rule.name] ? data[rule.name].length : 0
					if (rule.min && le < rule.min) {
						res = {
							isOk: false,
							errMsg: rule.errMsg
						}
					} else if (rule.max && le > rule.max) {
						res = {
							isOk: false,
							errMsg: rule.errMsg
						}
					}
					break
				case 'regex': // 自定义正则表达式
					// {name: 'xxx', type: 'regex', regex: /^1[0-9]{10,10}$/, errMsg: 'xxx'}
					if (rule.regex && !rule.regex.test(data[rule.name])) {
						res = {
							isOk: false,
							errMsg: rule.errMsg
						}
					}
					break
				case 'self': // 自定义校验函数
					// {name: 'xxx', type: 'self', validator: fnValidate}
					if (rule.validator) {
						res = rule.validator(rule.name, data[rule.name])
					}
					break
			}
			// 发现任何一个错误就立即返回，后面的不再判断
			if (!res.isOk) {
				if (!res.errMsg) {
					res.errMsg = '请正确填写数据' // 默认提示
				}
				return res
			}
		}
		return res
	}
}
